@@ -5,6 +5,7 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
+    "%s on %s" : "%s en %s",
     "Finished" : "Terminado",
     "To review" : "Para revisar",
     "Action needed" : "Acción requerida",
@@ -14,7 +15,9 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
     "No file was uploaded" : "No se cargó el archivo",
     "Missing a temporary folder" : "Falta una carpeta temporal",
+    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
     "Add card" : "Agregar tarjeta",
@@ -27,9 +30,11 @@ OC.L10N.register(
     "Undo" : "Deshacer",
     "Can edit" : "Puede editar",
     "Can share" : "Puede compartir",
+    "Owner" : "Dueño",
     "Delete" : "Borrar",
     "Edit" : "Editar",
     "Members" : "Miembros",
+    "Download" : "Descargar",
     "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
@@ -48,6 +53,11 @@ OC.L10N.register(
     "Shared with you" : "Compartido con usted",
     "Board details" : "Detalles del tablero",
     "Edit board" : "Editar el tablero",
+    "Unarchive board" : "Desarchivar tablero",
+    "Archive board" : "Archivar tablero",
+    "No notifications" : "No hay notificaciones",
+    "Delete board" : "Borrar tableros",
+    "Share" : "Compartir",
     "This week" : "Esta semana"
 },
 "nplurals=2; plural=(n != 1);");
