@@ -11,18 +11,23 @@ OC.L10N.register(
     "No file was uploaded" : "Nulle file esseva incargate",
     "Missing a temporary folder" : "Il manca un dossier temporari",
     "Cancel" : "Cancellar",
+    "Close" : "Clauder",
     "Details" : "Detalios",
     "Sharing" : "Compartente",
     "Tags" : "Etiquettas",
     "Undo" : "Disfacer",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Owner",
     "Delete" : "Deler",
     "Edit" : "Modificar",
     "Members" : "Membros",
+    "Download" : "Discargar",
     "Attachments" : "Attachamentos",
     "Comments" : "Commentarios",
     "Modified" : "Modificate",
+    "Today" : "Hodie",
+    "Tomorrow" : "Deman",
     "Save" : "Salveguardar",
     "Reply" : "Responder",
     "Update" : "Actualisation",
@@ -30,8 +35,8 @@ OC.L10N.register(
     "(group)" : "(gruppo)",
     "seconds ago" : "secundas passate",
     "Shared with you" : "Compartite con te",
-    "Today" : "Hodie",
-    "Tomorrow" : "Deman",
+    "No notifications" : "Nulle notificationes",
+    "Share" : "Compartir",
     "This week" : "Iste septimana"
 },
 "nplurals=2; plural=(n != 1);");
