@@ -71,6 +71,7 @@ OC.L10N.register(
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
     "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
+    "%s on %s" : "%s ant %s",
     "No data was provided to create an attachment." : "Priedo sukūrimui nebuvo pateikta jokių duomenų.",
     "Finished" : "Baigta",
     "To review" : "Reikia peržiūrėti",
@@ -159,8 +160,10 @@ OC.L10N.register(
     "Can edit" : "Gali redaguoti",
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
+    "Owner" : "Savininkas",
     "Delete" : "Ištrinti",
     "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
+    "Transfer" : "Persiųsti",
     "Add a new list" : "Pridėti naują sąrašą",
     "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
@@ -202,6 +205,8 @@ OC.L10N.register(
     "Select Date" : "Pasirinkti datą",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
+    "Next week" : "Kita savaitė",
+    "Next month" : "Kitas mėnuo",
     "Save" : "Įrašyti",
     "The comment cannot be empty." : "Komentaras negali būti tuščias.",
     "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
@@ -246,10 +251,10 @@ OC.L10N.register(
     "Delete board" : "Ištrinti lentą",
     "Board {0} deleted" : "Lenta {0} ištrinta",
     "Only assigned cards" : "Tik priskirtos kortelės",
+    "No reminder" : "Jokio priminimo",
     "An error occurred" : "Įvyko klaida",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
     "Delete the board?" : "Ištrinti lentą?",
-    "This week" : "Šią savaitę",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
     "Link to a board" : "Susieti su lenta",
@@ -260,6 +265,7 @@ OC.L10N.register(
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
     "Creating the new card…" : "Kuriama nauja kortelė…",
-    "(circle)" : "(ratas)"
+    "(circle)" : "(ratas)",
+    "This week" : "Šią savaitę"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
