@@ -168,8 +168,10 @@ OC.L10N.register(
     "Can edit" : "Lahko ureja",
     "Can share" : "Lahko omogoči souporabo",
     "Can manage" : "Lahko upravlja",
+    "Owner" : "Lastnik",
     "Delete" : "Izbriši",
     "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
+    "Transfer" : "Prenos",
     "Add a new list" : "Dodaj nov seznam",
     "Archive all cards" : "Arhiviraj vse kartice",
     "Delete list" : "Izbriši seznam",
@@ -238,6 +240,7 @@ OC.L10N.register(
     "Archive card" : "Arhiviraj nalogo",
     "Delete card" : "Izbriši nalogo",
     "Move card to another board" : "Premakni nalogo v drugo zbirko",
+    "List is empty" : "Seznam je prazen",
     "Card deleted" : "Naloga je izbrisana",
     "seconds ago" : "pred nekaj sekundami",
     "All boards" : "Vse zbirke",
@@ -266,7 +269,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
-    "This week" : "Ta teden",
     "No due" : "Ni datuma preteka",
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
@@ -282,6 +284,11 @@ OC.L10N.register(
     "Error creating the share" : "Napaka ustvarjanja mesta souporabe",
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta"
+    "Share" : "Souporaba",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
+    "Creating the new card…" : "Poteka ustvarjanje nove naloge ...",
+    "\"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
+    "(circle)" : "(krog)",
+    "This week" : "Ta teden"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
