@@ -168,8 +168,10 @@ OC.L10N.register(
     "Can edit" : "可以编辑",
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
+    "Owner" : "所有者",
     "Delete" : "删除",
     "Failed to create share with {displayName}" : "用 {displayName} 创建分享失败",
+    "Transfer" : "传输",
     "Add a new list" : "添加新列表",
     "Archive all cards" : "归档所有卡片",
     "Delete list" : "删除列表",
@@ -268,7 +270,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
     "Delete the board?" : "是否删除面板？",
     "Loading filtered view" : "正在加载已筛选的视图",
-    "This week" : "本周",
     "No due" : "没有到期的",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
@@ -288,6 +289,7 @@ OC.L10N.register(
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "“看板”是 Nextcloud 集成的一款看板式任务管理工具，用于个人计划与项目安排。\n\n\n- 📥 将您的任务添加到卡片上，并将它们有序排列\n- 📄 将您的补充说明用markdown写下来\n- 🔖 利用指派标签更好地进行筹划\n- 👥 与您的团队，朋友或家人共享\n- 📎 附加文件并将它们嵌入到您的markdown说明中\n- 💬 用评论与您的团队讨论\n- ⚡ 在活动流中紧跟变化\n- 🚀 使您的项目井井有条",
     "Creating the new card…" : "正在创建新卡片…",
     "\"{card}\" was added to \"{board}\"" : "\"{card}\" 被添加到 \"{board}\"",
-    "(circle)" : "(圈子)"
+    "(circle)" : "(圈子)",
+    "This week" : "本周"
 },
 "nplurals=1; plural=0;");
