@@ -170,8 +170,11 @@ OC.L10N.register(
     "Can edit" : "可以編輯",
     "Can share" : "可以分享",
     "Can manage" : "可以管理",
+    "Owner" : "所有者",
     "Delete" : "刪除",
     "Failed to create share with {displayName}" : "無法為 {displayName} 創建分享",
+    "Transfer the board." : "轉移面板。",
+    "Transfer" : "轉移",
     "Add a new list" : "添加一張新清單",
     "Archive all cards" : "封存所有卡片",
     "Delete list" : "刪除清單",
@@ -270,7 +273,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你確定你要刪除 {title} 面板嗎？面板內所有數據都將因此被刪除。",
     "Delete the board?" : "是否刪除面板？",
     "Loading filtered view" : "正在加載已過濾視圖",
-    "This week" : "本星期",
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
     "No results found" : "沒有結果",
@@ -290,6 +292,10 @@ OC.L10N.register(
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的項目井井有條",
     "Creating the new card…" : "正在建立新卡片...",
     "\"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
-    "(circle)" : "（社交圈子）"
+    "(circle)" : "（社交圈子）",
+    "This week" : "本星期",
+    "Are you sure you want to transfer the board {title} for {user} ?" : "您想要轉移 {user} 的面板 {title} 嗎？",
+    "Transfer the board for {user} successfully" : "轉移 {user} 的面板成功",
+    "Failed to transfer the board for {user}" : "轉移 {user} 的面板失敗"
 },
 "nplurals=1; plural=0;");
