@@ -28,8 +28,10 @@ class Board extends RelationalEntity {
 	protected $owner;
 	protected $color;
 	protected $archived = false;
-	protected $labels = [];
-	protected $acl = [];
+	/** @var Label[]|null */
+	protected $labels = null;
+	/** @var Acl[]|null */
+	protected $acl = null;
 	protected $permissions = [];
 	protected $users = [];
 	protected $shared;
@@ -61,6 +63,10 @@ class Board extends RelationalEntity {
 		if ($this->shared === -1) {
 			unset($json['shared']);
 		}
+		// FIXME: Ideally the API responses should follow the internal data structure and return null if the labels/acls have not been fetched from the db
+		// however this would be a breaking change for consumers of the API
+		$json['acl'] = $this->acl ?? [];
+		$json['labels'] = $this->labels ?? [];
 		return $json;
 	}
 
@@ -68,21 +74,27 @@ class Board extends RelationalEntity {
 	 * @param Label[] $labels
 	 */
 	public function setLabels($labels) {
-		foreach ($labels as $l) {
-			$this->labels[] = $l;
-		}
+		$this->labels = $labels;
 	}
 
 	/**
 	 * @param Acl[] $acl
 	 */
 	public function setAcl($acl) {
-		foreach ($acl as $a) {
-			$this->acl[] = $a;
-		}
+		$this->acl = $acl;
 	}
 
 	public function getETag() {
 		return md5((string)$this->getLastModified());
 	}
+
+	/** @returns Acl[]|null */
+	public function getAcl(): ?array {
+		return $this->acl;
+	}
+
+	/** @returns Label[]|null */
+	public function getLabels(): ?array {
+		return $this->labels;
+	}
 }
