@@ -101,9 +101,9 @@ class LabelMapper extends DeckMapper implements IPermissionMapper {
 		return ($row['owner'] === $userId);
 	}
 
-	public function findBoardId($labelId): ?int {
+	public function findBoardId($id): ?int {
 		try {
-			$entity = $this->find($labelId);
+			$entity = $this->find($id);
 			return $entity->getBoardId();
 		} catch (DoesNotExistException $e) {
 		} catch (MultipleObjectsReturnedException $e) {
