@@ -37,6 +37,7 @@ use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\CardCreatedEvent;
 use OCA\Deck\Event\CardDeletedEvent;
 use OCA\Deck\Event\CardUpdatedEvent;
+use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
 use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\LabelMapper;
@@ -45,6 +46,7 @@ use OCA\Deck\BadRequestException;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IUserManager;
+use OCP\IURLGenerator;
 
 class CardService {
 	private $cardMapper;
@@ -62,6 +64,7 @@ class CardService {
 	private $changeHelper;
 	private $eventDispatcher;
 	private $userManager;
+	private $urlGenerator;
 
 	public function __construct(
 		CardMapper $cardMapper,
@@ -78,6 +81,7 @@ class CardService {
 		IUserManager $userManager,
 		ChangeHelper $changeHelper,
 		IEventDispatcher $eventDispatcher,
+		IURLGenerator $urlGenerator,
 		$userId
 	) {
 		$this->cardMapper = $cardMapper;
@@ -95,6 +99,7 @@ class CardService {
 		$this->changeHelper = $changeHelper;
 		$this->eventDispatcher = $eventDispatcher;
 		$this->currentUser = $userId;
+		$this->urlGenerator = $urlGenerator;
 	}
 
 	public function enrich($card) {
@@ -154,7 +159,12 @@ class CardService {
 	}
 
 	public function findCalendarEntries($boardId) {
-		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
+		try {
+			$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
+		} catch (NoPermissionException $e) {
+			\OC::$server->getLogger()->error('Unable to check permission for a previously obtained board ' . $boardId, ['exception' => $e]);
+			return [];
+		}
 		$cards = $this->cardMapper->findCalendarEntries($boardId);
 		foreach ($cards as $card) {
 			$this->enrich($card);
@@ -596,4 +606,14 @@ class CardService {
 
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
 	}
+
+	public function getCardUrl($cardId) {
+		$boardId = $this->cardMapper->findBoardId($cardId);
+
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "#/board/$boardId/card/$cardId";
+	}
+
+	public function getRedirectUrlForCard($cardId) {
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "card/$cardId";
+	}
 }
